@@ -144,7 +144,10 @@ class VPS(_defaults_.Defaults):
 		# copy current source to vps & installer script.		
 		if log_level >= 0: loader.mark(new_message=f"Installing source code of website {self.domain} on vps {self.ip}")
 		package_name = gfp.name(path=self.root)
-		tmp = f"/tmp/{package_name}/"
+		if code_update:
+			tmp = self.library
+		else:
+			tmp = f"/tmp/{package_name}/"
 		response = ssht00ls.ssync.push(
 			alias=self.domain,
 			path=self.root,
@@ -156,11 +159,12 @@ class VPS(_defaults_.Defaults):
 		if not response.success: 
 			if log_level >= 0: loader.stop(success=False)
 			return r3sponse.error(f"Failed to deploy website {self.domain} on vps {self.ip}, error (#1): {response.error}.", log_level=log_level)
-		response = ssht00ls.ssh.command(
-			alias=self.domain,
-			command=f"rm -fr {tmp}/website.py",
-			log_level=-1,)
-		if not response.success: return response
+		r3sponse.log(f"&ORANGE&Do not forget&END& to remove the [{tmp}/website.py] file.")
+		#response = ssht00ls.ssh.command(
+		#	alias=self.domain,
+		#	command=f"rm -fr {tmp}/website.py",
+		#	log_level=-1,)
+		#if not response.success: return response
 
 		# execute installer script.
 		if not code_update:
